@@ -6,7 +6,6 @@ class Annotation(v1Object):
     
     def __init__(self):
         super().__init__()
-        self._api = 'aih'
         self._endpoint = 'api/v1/annotations'
         
     
@@ -17,14 +16,14 @@ class Annotation(v1Object):
         """
         
         if id:
-            self.value = self._client.get(self._api, f'{self._endpoint}/{id}')
+            self.value = self._client._get(self._api, f'{self._endpoint}/{id}')
             try:
                 self.value = self.value['annotation']
             except:
                 raise AIHE.AIHException(f'Annotation does not exist with id: {id}')
                 
         else:
-            self.value = self._client.get(self._api, self._endpoint)
+            self.value = self._client._get(self._api, self._endpoint)
             self.value = self.value['annotations']
         
         ## Sig fejl, hvis key error. Så er der ikke noget med det id i databasen
@@ -36,7 +35,7 @@ class Annotation(v1Object):
         To post the updates that have been made to self.value
         """
         
-        response_json = self._client.post(self._api, self._endpoint, self.value)
+        response_json = self._client._post(self._api, self._endpoint, self.value)
         self.value['id'] = response_json['annotation']['id']
         
         return self
